#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import logging

from model.config import LVS_METADATA

#
# CONSTANTS
#
TTY = 'console=tty0'
HVC = 'console=hvc0'
CRASHKERNEL = 'crashkernel=1024M'
TIMEOUT='rd.retry=720' # bugzilla:108694

class Grub:
    """Handle all grub operations"""

    def __init__(self):
        """
        Constructor
        """
        self.__logger = logging.getLogger(__name__)

    def setDefaultOptions(self, path, lvsOptions):
        """
        Set default options in /etc/default/grub

        Args:
            lvsOptions ([str]): kernel command line options
        """
        default = '%s %s %s %s ' % (TTY, HVC, CRASHKERNEL, TIMEOUT)
        default += ' '.join(lvsOptions)

        with open(path, 'w') as f:
            f.write("GRUB_CMDLINE_LINUX_DEFAULT=\"%s\"" % default)
            f.write("\nGRUB_DISABLE_SUBMENU=true")
            f.write("\nGRUB_DISABLE_RECOVERY=true")
            f.write("\nGRUB_DISABLE_OS_PROBER=true")
