#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *

from viewer.__data__ import CHOOSE_LANGUAGE
from viewer.__data__ import WELCOME_IBM_POWERKVM

#
# CONSTANTS
#


#
# CODE
#
class ChooseLanguage:
    """
    Welcome page for the installer application
    """

    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
            params (dict): screen input parameters. Valid keys:
                languages str languages which may be selected by user
        """
        self.__screen = screen
        self.__languages = params["languages"]
        self.__msg = TextboxReflowed(40, CHOOSE_LANGUAGE.localize())
        self.__list = Listbox(5, scroll=1, returnExit=1)

        self.__grid = GridForm(self.__screen, WELCOME_IBM_POWERKVM.localize() % params["productVersion"], 1, 2)
        self.__grid.add(self.__msg, 0, 0)
        self.__grid.add(self.__list, 0, 1, (0,1,0,0))

        self.__setMenuOptions(self.__languages)

    def run(self):
        """
        Draws the screen

        Returns:
            dict: screen output parameters. Valid keys:
            language str language selected by user
        """
        # run the list and show the window
        result = self.__grid.run()
        self.__screen.popWindow()

        # return the content to the controller
        return {"language": self.__list.current()}

    def __setMenuOptions(self, options):
        """
        Configures which options will be displayed on KoP menu install.

        Args:
            options ([(str, ?)]): list with tuples ('text', optionKey)
        """
        # invalid given parameter: abort
        if not isinstance(options, list):
            return

        # add options to screen list
        for opt in options:
            self.__list.append(opt[0], opt[1])
