#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import string

from snack import *

from viewer.__data__ import BACK
from viewer.__data__ import DNSSETUP_CONFIG_DNS
from viewer.__data__ import DNSSETUP_DNS_LIST_LABEL
from viewer.__data__ import DNSSETUP_DNS_LIST_TIP_LABEL
from viewer.__data__ import DNSSETUP_HOSTNAME_LABEL
from viewer.__data__ import DNSSETUP_HOSTNAME_TIP_LABEL
from viewer.__data__ import DNSSETUP_SEARCH_LABEL
from viewer.__data__ import OK
from viewer.__data__ import SKIP

#
# CONSTANTS
#


#
# CODE
#
class DNSSetup:
    """
    Represents the DNS configuration screen
    """

    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
            params (dict): screen input parameters
        """
        data_dns = params["dnsData"]

        self.__screen = screen
        self.__hostnameLabel = Label(DNSSETUP_HOSTNAME_LABEL.localize())
        self.__searchListLabel = Label(DNSSETUP_SEARCH_LABEL.localize())
        dnsListLabel = Label(DNSSETUP_DNS_LIST_LABEL.localize())

        hostname = params["hostname"]
        dnsList = data_dns['dnsList']
        searchList = data_dns['search']

        self.__hostname = Entry(48, hostname)
        self.__dnsList = Entry(48, ' '.join(dnsList))

        self.__searchList = Entry(48, searchList)
        self.__hostnameTip = Textbox(60, 2, DNSSETUP_HOSTNAME_TIP_LABEL.localize(),
                                     scroll = 0, wrap = 1)

        self.__dnsListTip = Textbox(60,
                                    2,
                                    DNSSETUP_DNS_LIST_TIP_LABEL.localize(),
                                    scroll=0,
                                    wrap=1)

        self.__hostnameGrid = Grid(2, 1)
        self.__hostnameGrid.setField(self.__hostnameLabel, 0, 0, anchorLeft=1)
        self.__hostnameGrid.setField(self.__hostname, 1, 0, (1, 0, 0, 0))

        self.__dnsAndSearchGrid = Grid(2, 2)
        self.__dnsAndSearchGrid.setField(dnsListLabel, 0, 0, anchorLeft=1)
        self.__dnsAndSearchGrid.setField(self.__dnsList, 1, 0, (1, 0, 0, 0))
        self.__dnsAndSearchGrid.setField(self.__searchListLabel, 0, 1, anchorLeft=1)
        self.__dnsAndSearchGrid.setField(self.__searchList, 1, 1, (1, 0, 0, 0))

        self.__buttonsBar = ButtonBar(self.__screen, [(OK.localize(),"ok"),
            (BACK.localize(), "back"), (SKIP.localize(), "skip")])

        self.__grid = GridForm(self.__screen, DNSSETUP_CONFIG_DNS.localize(),
                               1, 5)
        self.__grid.add(self.__hostnameTip, 0, 0)
        self.__grid.add(self.__hostnameGrid, 0, 1, (0,0,0,1))
        self.__grid.add(self.__dnsListTip, 0, 2)
        self.__grid.add(self.__dnsAndSearchGrid, 0, 3, (0, 0, 0, 1))
        self.__grid.add(self.__buttonsBar, 0, 4)

    def run(self):
        """
        Draws the screen

        Returns:
            dict: screen output parameters. Valid keys:
                pressedButton str pressed button ID
                dns dict DNS data. Valid keys: dnsList, search
                hostname str target system hostname
        """
        result = self.__grid.run()
        self.__screen.popWindow()

        dnsData = {}

        dnsList = self.__dnsList.value().replace(',', ' ')
        dnsList = dnsList.split()
        dnsData['dnsList'] = filter(None, [ns.strip() for ns in dnsList])

        dnsData['search'] = self.__searchList.value()

        return {"pressedButton": self.__buttonsBar.buttonPressed(result),
                "dnsData": dnsData,
                "hostname": self.__hostname.value(),}
