#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *
from viewer.__data__ import OK
from viewer.__data__ import IBM_POWERKVM
from viewer.__data__ import INSTALL_EXIT_CODE_MSG
from viewer.__data__ import LOG_AVAIL_MSG
from viewer.__data__ import ERROR_ERROR
from viewer.__data__ import ERROR_UNKNOWN


#
# CONSTANTS
#


#
# CODE
#
class GeneralErrorScreen:

    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
            params (dict): screen input parameters
        """
        self.__msg = params["errorMsg"]
        self.__screen = screen
        self.__title = IBM_POWERKVM.localize() % params["productVersion"]
        self.__logMsg = LOG_AVAIL_MSG.localize() % params["errorLogTarFile"]

    def run(self):
        """
        Displays an error when there is any error during installation

        Args:
            code (str): error code

        Returns:
            dict: screen output parameters
        """
        msg = INSTALL_EXIT_CODE_MSG.localize() % self.__msg

        table = []
        table.append(msg)
        table.append(self.__logMsg)

        ButtonChoiceWindow(self.__screen, self.__title,
                '\n'.join(table),
                buttons=[(OK.localize(), 'ok')],
                width = 50)

        return {}
