#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import os

from snack import *

from viewer.__data__ import ERROR_INSTALLATION
from viewer.__data__ import ERROR_INSTALLATION_MSG
from viewer.__data__ import IBM_POWERKVM
from viewer.__data__ import OK
from viewer.__data__ import PREPARING_TO_INSTALL_IBM_POWERKVM
from viewer.__data__ import WORKING


#
# CONSTANTS
#

#
# CODE
#
class InstallProgress:
    """
    Install PowerKVM into the disk
    """

    def __init__(self, screen, params):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
            params (dict): screen input parameters
        """
        self.__total = 0

        self.__screen = screen
        self.__progressBar = Scale(self.__screen.width-35, 100)
        self.__msg = TextboxReflowed(self.__screen.width-30,
                PREPARING_TO_INSTALL_IBM_POWERKVM.localize())

        self.__grid = GridForm(self.__screen, IBM_POWERKVM.localize() % params["productVersion"], 1, 3)
        self.__grid.add(self.__progressBar, 0, 0)
        self.__grid.add(self.__msg, 0, 1, (0, 1, 0, 0))

        self.__grid.draw()
        self.__screen.refresh()

        self.__installedPackages = 0

    def setMyMessage(self, msg, progress):
        """
        Update message in the screen
        """
        self.__msg.setText(msg)

        self.__total = int((progress + 50) / 1.66)
        self.__progressBar.set(self.__total)

        self.__grid.draw()
        self.__screen.refresh()

    def updateProgress(self, message, value):
        """
        Updates the progress bar

        Args:
             message (str): message to be displayed in progress box
             value (int): value to update the bar
        """
        self.__msg.setText(message)
        self.__progressBar.set(value)
        self.__grid.draw()
        self.__screen.refresh()

    def installInfo(self, data):
        """
        Callback to show install info progress
        """
        msg = ""

        # get operation from backend
        operation = str(data.get('operation', "Working"))

        # It is needed only the final part of operation: install-start
        if operation.endswith('install-start'):
            msg = "[0%%] %s" % data['package']

        # It is needed only the final part of operation: install
        elif operation.endswith('install'):
            msg = "[%s%%] %s" % (str(round(data['percent'], 2)), data['package'])

        # It is needed only the final part of operation: install-finish
        elif operation.endswith('install-finish'):
            self.__installedPackages += 1
            msg = "[100%%]: %s" % data['package']

        else:
            msg = WORKING.localize()

        total_pkgs = data['total_pkgs']

        # calculate progress
        progress = int(float(float(self.__installedPackages)/float(total_pkgs)) * 100)

        self.setMyMessage(msg, progress)

    def showGeneralError(self):
        """
        Displays an error when there is any error during installation
        """
        ButtonChoiceWindow(self.__screen, ERROR_INSTALLATION.localize(),
                           ERROR_INSTALLATION_MSG.localize(),
                           buttons=[(OK.localize(), 'ok')],
                           width=50)
