#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *

from model.config import STR_VERSION
from viewer.__data__ import BACK
from viewer.__data__ import ERROR_PASSWD_LENGTH
from viewer.__data__ import ERROR_PASSWD_LENGTH_MSG
from viewer.__data__ import ERROR_PASSWD_MISMATCH
from viewer.__data__ import ERROR_PASSWD_MISMATCH_MSG
from viewer.__data__ import OK
from viewer.__data__ import PASSWD_CONFIRM_LABEL
from viewer.__data__ import PASSWD_LABEL
from viewer.__data__ import PASSWD_WINDOW_MSG
from viewer.__data__ import PASSWD_WINDOW_TITLE


#
# CONSTANTS
#


#
# CODE
#
class RootChangePassword:
    """
    Represents the root change password screen
    """

    def __init__(self, screen, params):
        """
        Constructor

        Args:
             screen (SnackScreen): SnackScreen instance
        """
        self.__screen = screen

        self.__msg = TextboxReflowed(40, PASSWD_WINDOW_MSG.localize())

        self.__buttonsBar = ButtonBar(self.__screen, [(OK.localize(), "ok"),
            (BACK.localize(), 'back')])

        self.__passwd = Entry(24, "", password=1)
        self.__passwdConfirm = Entry(24, "", password=1)

        passwdLabel = Label(PASSWD_LABEL.localize())
        passwdConfirmLabel = Label(PASSWD_CONFIRM_LABEL.localize())

        self.__passwdGrid = Grid(2, 2)
        self.__passwdGrid.setField(passwdLabel, 0, 0, anchorLeft=1)
        self.__passwdGrid.setField(passwdConfirmLabel, 0, 1, anchorLeft=1)
        self.__passwdGrid.setField(self.__passwd, 1, 0)
        self.__passwdGrid.setField(self.__passwdConfirm, 1, 1)


    def __runUI(self):

        # show UI
        # tricky: in Newt, form creation and form display are coupled in GridForm(), so
        # form creation must be done here
        self.__grid = GridForm(self.__screen, PASSWD_WINDOW_TITLE.localize(), 1, 3)
        self.__grid.add(self.__msg, 0, 0)
        self.__grid.add(self.__passwdGrid, 0, 1, (0, 1, 0, 0))
        self.__grid.add(self.__buttonsBar, 0, 2, (0, 1, 0, 0))

        self.__grid.setCurrent(self.__passwd)
        self.__screen.refresh()

        # get user input
        result = self.__grid.run()

        # hide UI
        self.__screen.popWindow()

        return self.__buttonsBar.buttonPressed(result)

    def run(self):
        """
        Shows screen once

        Returns:
            int: status of operation
        """

        validInput = False
        while not validInput:
            pressedButton = self.__runUI()

            passwd = self.__passwd.value()
            confirm = self.__passwdConfirm.value()

           # check password confirmation
            if passwd != confirm:
                self.showErrorMismatch()
                continue

            validInput = True

        return {"pressedButton": pressedButton,
                "passwd": passwd}


    def showErrorLength(self):
        """
        Displays an error about the password length
        """
        ButtonChoiceWindow(self.__screen, ERROR_PASSWD_LENGTH.localize(),
                           ERROR_PASSWD_LENGTH_MSG.localize(),
                           buttons=[(OK.localize(), 'ok')],
                           width=50)

    def showErrorMismatch(self):
        """
        Displays an error about the password mismatch
        """
        ButtonChoiceWindow(self.__screen, ERROR_PASSWD_MISMATCH.localize(),
                           ERROR_PASSWD_MISMATCH_MSG.localize(),
                           buttons=[(OK.localize(), 'ok')],
                           width = 50)
