# -*- coding: utf-8 -*-

#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======



def genDateStr(dateFormat, year, month, day):
    """
    Return a formatted string of a given date.

    Args:

        dateFormat (str): date format (some permutation of D, M and Y -
            separated by spaces).
        year (str): year to be used when formatting the date.
        month (str): month to be used when formatting the date.
        day (str): day to be used when formatting the date.

    Returns:
        str: something like 2015/03/09 or 09/03/2015
    """
    tmp = '/'.join(dateFormat.split())
    tmp = tmp.replace('Y', year, 1)
    tmp = tmp.replace('M', month.zfill(2), 1)
    str = tmp.replace('D', day.zfill(2), 1)
    return str

def genTimeStr(hour, minute, seconds):
    """
    Return a formatted time string for the given parameters.

    Args:
        hour (str): hour to be used for formatting the string.
        minute (str): minute to be used for formatting the string.
        seconds (str): seconds to be used for formatting the string.

    Returns:
        str: something like 09:33:46
    """
    return ':'.join(map(lambda x: x.zfill(2), [hour, minute, seconds]))

def addFieldToGrid(grid, value, col, line, anchorL = 1, anchorR = 0):
    """
    Adds a field to a given grid.
    """
    grid.setField(value, col, line, anchorLeft = anchorL,
                  anchorRight = anchorR)

def addJoinedFieldsToGrid(grid, sep, fields, column, line):
    """
    Adds multiple fields to a grid (all on the same line) using a
        separator between the fields.
    """
    from snack import Label
    for field in fields[:-1]:
        addFieldToGrid(grid, field, column, line)
        column = column + 1
        addFieldToGrid(grid, Label(sep), column, line)
        column = column + 1

    addFieldToGrid(grid, fields[-1], column, line)
    return column + 1
