#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *

from __data__ import HELP_LINE
from newt.adjusttimezone import AdjustTimezone
from newt.chooselanguage import ChooseLanguage
from newt.confirmation import Confirmation
from newt.datetimesetup import DateTimeSetup
from newt.dnssetup import DNSSetup
from newt.splashscreen import SplashScreen
from newt.generalerrorscreen import GeneralErrorScreen
from newt.installationsummary import InstallationSummary
from newt.installprogress import InstallProgress
from newt.licensewindow import LicenseMainWindow
from newt.listnetworkifaces import ListNetworkifaces
from newt.menu import Menu
from newt.messagewindow import MessageWindow
from newt.networkconfig import NetworkConfig
from newt.ntpsetup import NTPSetup
from newt.rebootsystem import RebootSystem
from newt.reinstallerror import ReinstallError
from newt.resizelogicalvolume import ResizeLogicalVolume
from newt.rootchangepassword import RootChangePassword
from newt.selectharddisk import SelectHardDisk
from newt.selectpreviousinstallation import SelectPreviousInstallation
from screen_ids import ScreenIds



viewMap = {
           ScreenIds.CONFIRM_INSTALLATION: Confirmation,
           ScreenIds.SPLASH: SplashScreen,
           ScreenIds.GENERAL_ERROR: GeneralErrorScreen,
           ScreenIds.INSTALLATION_PROGRESS: InstallProgress,
           ScreenIds.INSTALLATION_SUMMARY: InstallationSummary,
           ScreenIds.LICENSE: LicenseMainWindow,
           ScreenIds.LIST_NETWORK_INTERFACES: ListNetworkifaces,
           ScreenIds.MENU: Menu,
           ScreenIds.MESSAGE: MessageWindow,
           ScreenIds.REBOOT: RebootSystem,
           ScreenIds.REINSTALLATION_ERROR: ReinstallError,
           ScreenIds.SELECT_DISKS: SelectHardDisk,
           ScreenIds.SELECT_PREV_INSTALL: SelectPreviousInstallation,
           ScreenIds.SELECT_LANGUAGE: ChooseLanguage,
           ScreenIds.SELECT_TIMEZONE: AdjustTimezone,
           ScreenIds.SETUP_DATETIME: DateTimeSetup,
           ScreenIds.SETUP_DNS: DNSSetup,
           ScreenIds.SETUP_LVM: ResizeLogicalVolume,
           ScreenIds.SETUP_NETWORK_INTERFACE: NetworkConfig,
           ScreenIds.SETUP_NTP: NTPSetup,
           ScreenIds.SETUP_ROOT_PASSWORD: RootChangePassword
          }

#
# CODE
#
class Viewer(object):
    """
    Creates views
    """
    def __init__(self):
        """
        Initialize viewer
        """
        self.__screenStack = []
        self.__snackScreen = SnackScreen()
        self.__snackScreen.pushHelpLine(HELP_LINE.localize())

    def destructor(self):
        """
        Finishes viewer
        """
        self.__snackScreen.finish()

    def createView(self, screenId, params=None):
        """
        Create a view

        Args:
            screenId (int): screen ID
            params (dict): view input parameters

        Returns:
            object: view
        """

        view = viewMap[screenId](self.__snackScreen, params)
        self.__screenStack.append(screenId)
        return view

    def runView(self, screenId, params=None):
        """
        Create and run a view

        Args:
            screenId (int): screen ID
            params (dict): view input parameters

        Returns:
            tuple: str: result
                   dict: output variables
        """

        view = self.createView(screenId, params)
        return view.run()

    def popScreens(self, numPops=1):
        """
        Pop screens from screen stack
        """

        for i in range(numPops):
            if len(self.__screenStack) == 0:
                raise Exception("Unable to pop screen from screen stack, stack is empty")
            screenId = self.__screenStack.pop()
        return screenId

    def popPrevScreen(self):
        """
        Pop current and previous screen from screen stack.
        This is just a convenience method.
        """

        return self.popScreens(2)

# Viewer
